@@ -8,10 +8,10 @@ class StaticHandler(object):
         self.server_name = server_name
         try:
             self.cache = INotifyCache()
-            print "static cache: INotifyCache"
+            #print "static cache: INotifyCache"
         except:
             self.cache = NaiveCache()
-            print "static cache: NaiveCache"
+            #print "static cache: NaiveCache"
 
     def __call__(self, req, prefix, directory):
         path = os.path.join(directory, req.url[len(prefix):])
@@ -53,4 +53,4 @@ class StaticHandler(object):
         if data == "":
             return response.end()
         self.cache.add_content(path, data)
-        response.write(data, self.__write_file, [response, openfile, path])
+        response.write(data, self.__write_file, [response, openfile, path])
\ No newline at end of file
